summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/mutation.cc
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2009-02-25 06:10:42 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2009-02-25 06:10:42 +0000
commit4e53f8d9cc72c28e1d4bade77aaa8e20bb174d11 (patch)
tree9d4e932133512abc82dfdcbd1953632ad926317f /crawl-ref/source/mutation.cc
parent5403e4a838304257c39536491302d097c5dbe732 (diff)
downloadcrawl-ref-4e53f8d9cc72c28e1d4bade77aaa8e20bb174d11.tar.gz
crawl-ref-4e53f8d9cc72c28e1d4bade77aaa8e20bb174d11.zip
Disallow vampires' getting the regeneration or slow healing mutations,
since their healing rate depends on their blood level. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@9208 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/mutation.cc')
-rw-r--r--crawl-ref/source/mutation.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/crawl-ref/source/mutation.cc b/crawl-ref/source/mutation.cc
index 1d2406979e..987b84dfaf 100644
--- a/crawl-ref/source/mutation.cc
+++ b/crawl-ref/source/mutation.cc
@@ -2037,10 +2037,11 @@ bool mutate(mutation_type which_mutation, bool failMsg,
if (mutat == MUT_BIG_WINGS && !player_genus(GENPC_DRACONIAN))
return (false);
// Vampires' thirst rate depends on their blood level.
if (you.species == SP_VAMPIRE
- && (mutat == MUT_SLOW_METABOLISM || mutat == MUT_FAST_METABOLISM
- || mutat == MUT_CARNIVOROUS || mutat == MUT_HERBIVOROUS))
+ && (mutat == MUT_CARNIVOROUS || mutat == MUT_HERBIVOROUS
+ || mutat == MUT_REGENERATION || mutat == MUT_SLOW_HEALING
+ || mutat == MUT_FAST_METABOLISM || mutat == MUT_SLOW_METABOLISM))
{
return (false);
}
@@ -2037,10 +2037,11 @@ bool mutate(mutation_type which_mutation, bool failMsg,
if (mutat == MUT_BIG_WINGS && !player_genus(GENPC_DRACONIAN))
return (false);
- // Vampires' thirst rate depends on their blood level.
+ // Vampires' healing and thirst rates depend on their blood level.
if (you.species == SP_VAMPIRE